==> rendition-11.20.2.tgz: package/dist_esm5/components/Steps/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import FaCheckMarkCircle from 'react-icons/lib/fa/check-circle';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { DismissableContainer } from '../../internal/DismissableContainer';
import { px } from '../../utils';
import { Flex } from '../Flex';
import Heading from '../Heading';
import Link from '../Link';
import Txt from '../Txt';
import { Arrow } from './Arrow';
var getStatusColor = function (theme, status) {
    switch (status) {
        case 'pending':
            return theme.colors.tertiary.semilight;
        case 'completed':
            return theme.colors.success.main;
    }
};
var StatusIconPlaceholder = styled.span(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tfont-size: ", ";\n\tcolor: ", ";\n\tline-height: 0.8; /* We need this to normalize the icon's height */\n"], ["\n\tfont-size: ", ";\n\tcolor: ", ";\n\tline-height: 0.8; /* We need this to normalize the icon's height */\n"])), function (props) { return px(props.theme.fontSizes[5]); }, function (props) { return getStatusColor(props.theme, props.status); });
var HeaderContainer = styled(Flex)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tmin-height: 32px;\n"], ["\n\tmin-height: 32px;\n"])));
export var Step = function (_a) {
    var status = _a.status, children = _a.children, onClick = _a.onClick;
    if (typeof children !== 'string') {
        throw new Error('The child of a Step has to be a string.');
    }
    return (React.createElement(Flex, { flexDirection: "row", justifyContent: "center", alignItems: "center" },
        React.createElement(StatusIconPlaceholder, { status: status },
            React.createElement(FaCheckMarkCircle, null)),
        onClick ? (React.createElement(Link, { ml: 2, onClick: onClick }, children)) : (React.createElement(Txt, { ml: 2 }, children))));
};
var FramelessSteps = function (_a) {
    var children = _a.children, otherProps = __rest(_a, ["children"]);
    return (React.createElement(Flex, __assign({ mx: "auto", flexDirection: "row", alignItems: "center", flexWrap: "wrap" }, otherProps), React.Children.map(children, function (step, index) {
        if (step.type !== Step) {
            throw new Error('You can only use Step components as children of Steps.');
        }
        return (React.createElement(Flex, { flexDirection: "row", alignItems: "center" },
            step,
            index < children.length - 1 && (React.createElement(Flex, { justifyContent: "center", alignItems: "center", mx: 3 },
                React.createElement(Arrow, null)))));
    })));
};
var Steps = React.forwardRef(function (_a, ref) {
    var className = _a.className, children = _a.children, titleText = _a.titleText, titleIcon = _a.titleIcon, onClose = _a.onClose;
    return (React.createElement(DismissableContainer, { p: 3, className: className, flexDirection: "row", justifyContent: "space-between", flexWrap: "wrap", alignItems: "center", onDismiss: onClose, baselineHeight: 32, ref: ref },
        (titleText || titleIcon) && (React.createElement(HeaderContainer, { justifyContent: "center", alignItems: "center", ml: 2, mr: 4 },
            titleIcon && (React.createElement(Txt, { fontSize: 2, mr: 2 }, titleIcon)),
            titleText && React.createElement(Heading.h6, null, titleText))),
        React.createElement(FramelessSteps, null, children)));
});
export default asRendition(Steps);
var templateObject_1, templateObject_2;

==> rendition-11.21.1.tgz: package/dist_esm5/components/Steps/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import FaCheckMarkCircle from 'react-icons/lib/fa/check-circle';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { DismissableContainer } from '../../internal/DismissableContainer';
import { px } from '../../utils';
import { Flex } from '../Flex';
import Heading from '../Heading';
import Link from '../Link';
import Txt from '../Txt';
import { Arrow } from './Arrow';
var getStatusColor = function (theme, status) {
    switch (status) {
        case 'pending':
            return theme.colors.tertiary.semilight;
        case 'completed':
            return theme.colors.success.main;
    }
};
var StatusIconPlaceholder = styled.span(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tfont-size: ", ";\n\tcolor: ", ";\n\tline-height: 0.8; /* We need this to normalize the icon's height */\n"], ["\n\tfont-size: ", ";\n\tcolor: ", ";\n\tline-height: 0.8; /* We need this to normalize the icon's height */\n"])), function (props) { return px(props.theme.fontSizes[5]); }, function (props) { return getStatusColor(props.theme, props.status); });
var HeaderContainer = styled(Flex)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tmin-height: ", ";\n"], ["\n\tmin-height: ", ";\n"])), function (props) { return px(props.theme.fontSizes[5]); });
export var Step = function (_a) {
    var status = _a.status, children = _a.children, onClick = _a.onClick;
    if (typeof children !== 'string') {
        throw new Error('The child of a Step has to be a string.');
    }
    return (React.createElement(Flex, { flexDirection: "row", justifyContent: "center", alignItems: "center" },
        React.createElement(StatusIconPlaceholder, { status: status },
            React.createElement(FaCheckMarkCircle, null)),
        onClick ? (React.createElement(Link, { ml: 2, onClick: onClick }, children)) : (React.createElement(Txt, { ml: 2 }, children))));
};
var FramelessSteps = function (_a) {
    var children = _a.children, otherProps = __rest(_a, ["children"]);
    return (React.createElement(Flex, __assign({ mx: "auto", flexDirection: "row", alignItems: "center", flexWrap: "wrap" }, otherProps), React.Children.map(children, function (step, index) {
        if (step.type !== Step) {
            throw new Error('You can only use Step components as children of Steps.');
        }
        return (React.createElement(Flex, { flexDirection: "row", alignItems: "center" },
            step,
            index < children.length - 1 && (React.createElement(Flex, { justifyContent: "center", alignItems: "center", mx: 3 },
                React.createElement(Arrow, null)))));
    })));
};
var Steps = React.forwardRef(function (_a, ref) {
    var className = _a.className, children = _a.children, titleText = _a.titleText, titleIcon = _a.titleIcon, onClose = _a.onClose;
    return (React.createElement(DismissableContainer, { p: 3, className: className, flexDirection: "row", justifyContent: "space-between", flexWrap: "wrap", alignItems: "center", onDismiss: onClose, baselineHeight: 32, ref: ref },
        (titleText || titleIcon) && (React.createElement(HeaderContainer, { justifyContent: "center", alignItems: "center", ml: 2, mr: 4 },
            titleIcon && (React.createElement(Txt, { fontSize: 2, mr: 2, color: "tertiary.semilight" }, titleIcon)),
            titleText && (React.createElement(Heading.h6, { color: "tertiary.main" }, titleText)))),
        React.createElement(FramelessSteps, null, children)));
});
export default asRendition(Steps);
var templateObject_1, templateObject_2;
